summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmsoredit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmsoredit.h')
-rw-r--r--kpovmodeler/pmsoredit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmsoredit.h b/kpovmodeler/pmsoredit.h
index 1c7c57fd..3858dd11 100644
--- a/kpovmodeler/pmsoredit.h
+++ b/kpovmodeler/pmsoredit.h
@@ -43,12 +43,13 @@ class PMVectorListEdit;
class PMSurfaceOfRevolutionEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSurfaceOfRevolutionEdit with parent and name
*/
- PMSurfaceOfRevolutionEdit( TQWidget* parent, const char* name = 0 );
+ PMSurfaceOfRevolutionEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -43,12 +43,13 @@ class PMVectorListEdit;
public:
/**
- * Creates a PMSurfaceOfRevolutionEdit with parent and name
+ * Creates a PMSurfaceOfRevolutionEdit with tqparent and name
*/